#
# spec file for package python-apicapi
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global  sname  apicapi
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
# package does not support python3 at all (uses iteritems/etc)
%define  skip_python3 1
Name:           python-apicapi
Version:        1.6.0
Release:        lp152.3.1
Summary:        Python interface to the APIC REST API
License:        Apache-2.0
URL:            https://github.com/noironetworks/apicapi/
Source:         https://github.com/noironetworks/apicapi/archive/%{version}.tar.gz
# https://github.com/noironetworks/apicapi/pull/85
Source99:       http://www.apache.org/licenses/LICENSE-2.0.txt
Patch1:         python-apicapi-disableparseconfigtest.patch
BuildRequires:  %{python_module SQLAlchemy}
BuildRequires:  %{python_module WebOb}
BuildRequires:  %{python_module click >= 5.1}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module oslo.config >= 1.4.0}
BuildRequires:  %{python_module pbr}
BuildRequires:  %{python_module pyOpenSSL}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module testtools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-SQLAlchemy
Requires:       python-click >= 5.1
Requires:       python-oslo.config >= 1.4.0
Requires:       python-pyOpenSSL
Requires:       python-requests
BuildArch:      noarch
%python_subpackages

%description
This library provides an interface for the APIC REST API, for use by
the other Cisco APIC Python packages.

%prep
%setup -q -n %{sname}-%{version}
%patch1 -p1
cp %{SOURCE99} .

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# Install other supporting files (like bash_completions)
install -p -D -m 644 etc/apic.bash_completion \
    %{buildroot}%{_datadir}/bash-completion/completions/apic

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} $python -m unittest discover -s apicapi/tests/unit

%files %{python_files}
%license LICENSE-2.0.txt
%doc AUTHORS README.rst
%{python_sitelib}/%{sname}
%{python_sitelib}/%{sname}-%{version}*.egg-info
%{_bindir}/apic
%{_bindir}/apic-bond-watch
%{_datadir}/bash-completion/completions/apic

%changelog
* Tue Nov  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Format with spec-cleaner
* Tue Oct 30 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Sun Oct 28 2018 ashwin.agate@suse.com
- Disable test_api_config.TestConfigParse.test_parse_file
  because of intermittent failures.
  (add python-apicapi-disableparseconfigtest.patch)
* Wed Oct 24 2018 Tomáš Chvátal <tchvatal@suse.com>
- Install license
- Clean up with spec-cleaner
- Install bash completion to proper dir
- Run the tests and add all the required test dependencies
- Update to 1.6.0:
  * 1.0 series seem to work with oslo < 4.0
* Thu Oct 18 2018 sma@suse.com
- Changed the spec file:
  * changed to singlespec format but only made it
  * only build the python2 packages.
  * more cleanup on the Requires list
* Thu Oct 18 2018 sma@suse.com
- Changed to 1.0.20.
- Spec file cleanup:
  * The pkg requirement list in the spec file now matches
    requirements.txt
  * Made /etc/bash_completion.d/apic.bash_completion a
    config file.
  * Script apic-cleanup is removed in version 1.0.20.
* Fri Aug 25 2017 mmnelemane@suse.com
- Changed to 1.0.14 for APIC firmware 2.2.2
* Wed Jul 26 2017 mmnelemane@suse.com
- Updated to 1.0.15
* Tue Nov 22 2016 veerapuram.varadhan@microfocus.com
- update to 1.0.12
* Wed May 18 2016 dmueller@suse.com
- update to 1.0.9
* Tue Feb  9 2016 tbechtold@suse.com
- Initial packaging (version 1.0.6)
